@@ -1,3 +1,3 @@
 #!/bin/sh
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
-'/usr/bin/ghc-pkg' 'unregister' '--force' '--global' 'QuickCheck-2.8.2' "$@"
+'/usr/bin/ghc-pkg' 'unregister' '--force' '--global' 'QuickCheck-2.8' "$@"
